@@ -1,6 +1,6 @@
 package X11::XCB::Sizehints;
 
-use Moose;
+use Mouse;
 use Data::Dumper;
 use X11::XCB qw(:all);
 use X11::XCB::Sizehints::Aspect;
@@ -20,7 +20,7 @@ sub _update_aspect {
     $hints->set_aspect($aspect->min_num, $aspect->min_den,
                        $aspect->max_num, $aspect->max_den);
 
-    X11::XCB::ICCCM::set_wm_size_hints($self->_conn->conn, $self->window, ATOM_WM_NORMAL_HINTS, $hints);
+    X11::XCB::ICCCM::set_wm_size_hints($self->_conn, $self->window, ATOM_WM_NORMAL_HINTS, $hints);
 }
 
 =head1 NAME
